Index: webrtc/media/engine/webrtcvoiceengine.h |
diff --git a/webrtc/media/engine/webrtcvoiceengine.h b/webrtc/media/engine/webrtcvoiceengine.h |
index ea48544924ae0ce5c096c05a404f7ff5798319d1..f9c4f190dfb70c1534473ea8f88ca6d4dcaa37fd 100644 |
--- a/webrtc/media/engine/webrtcvoiceengine.h |
+++ b/webrtc/media/engine/webrtcvoiceengine.h |
@@ -233,12 +233,12 @@ class WebRtcVoiceMediaChannel final : public VoiceMediaChannel, |
void ChangePlayout(bool playout); |
int CreateVoEChannel(); |
bool DeleteVoEChannel(int channel); |
- bool IsDefaultRecvStream(uint32_t ssrc) { |
- return default_recv_ssrc_ == static_cast<int64_t>(ssrc); |
- } |
bool SetMaxSendBitrate(int bps); |
bool ValidateRtpParameters(const webrtc::RtpParameters& parameters); |
void SetupRecording(); |
+ // Check if 'ssrc' is an unsignaled stream, and if so mark it as not being |
+ // unsignaled anymore (i.e. it is now removed, or signaled). |
Taylor Brandstetter
2017/02/17 10:34:46
nit: add "and return true"
the sun
2017/02/17 11:22:47
Done.
|
+ bool MaybeDeregisterUnsignaledRecvStream(uint32_t ssrc); |
rtc::ThreadChecker worker_thread_checker_; |
@@ -257,11 +257,12 @@ class WebRtcVoiceMediaChannel final : public VoiceMediaChannel, |
webrtc::Call* const call_ = nullptr; |
webrtc::Call::Config::BitrateConfig bitrate_config_; |
- // SSRC of unsignalled receive stream, or -1 if there isn't one. |
- int64_t default_recv_ssrc_ = -1; |
- // Volume for unsignalled stream, which may be set before the stream exists. |
+ // Queue of unsignaled SSRCs; oldest at the beginning. |
+ std::vector<uint32_t> unsignaled_recv_ssrcs_; |
+ |
+ // Volume for unsignaled streams, which may be set before the stream exists. |
double default_recv_volume_ = 1.0; |
// Sink for unsignalled stream, which may be set before the stream exists. |
std::unique_ptr<webrtc::AudioSinkInterface> default_sink_; |
// Default SSRC to use for RTCP receiver reports in case of no signaled |
// send streams. See: https://code.google.com/p/webrtc/issues/detail?id=4740 |
@@ -257,11 +257,12 @@ class WebRtcVoiceMediaChannel final : public VoiceMediaChannel, |
double default_recv_volume_ = 1.0; |
- // Sink for unsignalled stream, which may be set before the stream exists. |
+ // Sink for latest unsignaled stream - may be set before the stream exists. |
std::unique_ptr<webrtc::AudioSinkInterface> default_sink_; |
// Default SSRC to use for RTCP receiver reports in case of no signaled |